@@ -15,3 +15,6 @@ from .dispatch import Dispatcher
 
 from .dson import DsonManager, DsonBase, nextpcgmethod, DsonMetaInfo
 from .dson_create import create_dson_from_pda
+from . import plugin_protocol
+
+# from .dson_pool import DsonPool, DsonTask
\ No newline at end of file
